@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.16
+0.17
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,7 @@ use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE_
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 use constant OFFLINE => $ENV{MOJO_IRC_OFFLINE} ? 1 : 0;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -492,7 +492,7 @@ sub irc_nick {
   my ($self, $message) = @_;
   my $old_nick = ($message->{prefix} =~ /^[~&@%+]?(.*?)!/)[0] || '';
 
-  if ($old_nick eq $self->nick) {
+  if (lc $old_nick eq lc $self->nick) {
     $self->nick($message->{params}[0]);
   }
 }
@@ -527,12 +527,13 @@ sub irc_ping {
 =head2 irc_rpl_welcome
 
 Used to get the hostname of the server. Will also set up automatic PING
-requests to prevent timeout.
+requests to prevent timeout and update the L</nick> attribute.
 
 =cut
 
 sub irc_rpl_welcome {
   my ($self, $message) = @_;
+  $self->nick($message->{params}[0]);
 
   Scalar::Util::weaken($self);
   $self->real_host($message->{prefix});
@@ -576,19 +577,20 @@ sub _read {
   no warnings 'utf8';
   $self->{buffer} .= Unicode::UTF8::decode_utf8($_[0], sub { $_[0] });
 
+CHUNK:
   while ($self->{buffer} =~ s/^([^\r\n]+)\r\n//m) {
     warn "[$self->{debug_key}] >>> $1\n" if DEBUG;
     my $message = $self->parser->parse($1);
-    my $method = $message->{command} || '';
+    my $command = $message->{command} or next CHUNK;
 
-    if ($method =~ /^\d+$/) {
-      $self->emit("irc_$method" => $message);
-      $method = IRC::Utils::numeric_to_name($method) or return;
+    if ($command =~ /^\d+$/) {
+      $self->emit("irc_$command" => $message);
+      $command = IRC::Utils::numeric_to_name($command) or next CHUNK;
     }
 
-    $method = "irc_$method" if $method !~ /^(CTCP|ERR)_/;
-    $self->emit(lc($method) => $message);
-    $self->emit(irc_error => $message) if $method =~ /^ERR_/;
+    $command = "irc_$command" if $command !~ /^(CTCP|ERR)_/;
+    $self->emit(lc($command) => $message);
+    $self->emit(irc_error => $message) if $command =~ /^ERR_/;
   }
 }
 
